#    Copyright (C) 1995, 1996 Aladdin Enterprises.  All rights reserved.
# 
# This file is part of GNU Ghostscript.
# 
# GNU Ghostscript is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility to
# anyone for the consequences of using it or for whether it serves any
# particular purpose or works at all, unless he says so in writing.  Refer to
# the GNU General Public License for full details.
# 
# Everyone is granted permission to copy, modify and redistribute GNU
# Ghostscript, but only under the conditions described in the GNU General
# Public License.  A copy of this license is supposed to have been given to
# you along with GNU Ghostscript so you can know your rights and
# responsibilities.  It should be in a file named COPYING.  Among other
# things, the copyright notice and this notice must be preserved on all
# copies.
# 
# Aladdin Enterprises is not affiliated with the Free Software Foundation or
# the GNU Project.  GNU Ghostscript, as distributed by Aladdin Enterprises,
# does not depend on any other GNU software.

# makefile for Unix / gcc library testing.

gsdir = /usr/local/share/ghostscript
gsdatadir = $(gsdir)/4.03
GS_DOCDIR=$(gsatadir)/doc
GS_LIB_DEFAULT=$(gsdatadir):$(gsdir)/fonts
GS_INIT=gs_init.ps

GENOPT=-DDEBUG
GS=gslib

JSRCDIR=jpeg-6a
JVERSION=6
CONFIG=

CC=gcc
CCLD=$(CC)

GCFLAGS=-Wall -Wpointer-arith -Wstrict-prototypes -Wwrite-strings
CFLAGS=-g -O $(GCFLAGS) $(XCFLAGS)
LDFLAGS=$(XLDFLAGS)
EXTRALIBS=
XINCLUDE=-I/usr/local/X/include
XLIBDIRS=-L/usr/local/X/lib
XLIBDIR=
XLIBS=Xt Xext X11

FPU_TYPE=1

FEATURE_DEVS=patlib.dev path1lib.dev hsblib.dev
COMPILE_INITS=0
DEVICE_DEVS=x11.dev

MAKEFILE=ugcclib.mak

AK=
CCAUX=$(CC)
CCC=$(CC) $(CCFLAGS) -c
CCLEAF=$(CCC)
# When using gcc, CCA2K isn't needed....
CCA2K=$(CC)

include unixhead.mak

include gs.mak
include lib.mak
include jpeg.mak
include libpng.mak
include zlib.mak
include devs.mak

# Following is from unixtail.mak, we have a different link step.
unix__=gp_nofb.o gp_unix.o gp_unifs.o gp_unifn.o
unix_.dev: $(unix__)
	$(SETMOD) unix_ $(unix__)

gp_unix.o: gp_unix.c $(AK) $(string__h) $(gx_h) $(gsexit_h) $(gp_h) \
  $(time__h)

sysv__=gp_nofb.o gp_unix.o gp_unifs.o gp_unifn.o gp_sysv.o
sysv_.dev: $(sysv__)
	$(SETMOD) sysv_ $(sysv__)

gp_sysv.o: gp_sysv.c $(time__h) $(AK)

ansi2knr: ansi2knr.c $(stdio__h) $(string__h) $(malloc__h)
	$(CCA2K) $(O)ansi2knr ansi2knr.c

echogs: echogs.c
	$(CCAUX) $(O)echogs echogs.c

genarch: genarch.c $(stdpre_h) $(iref_h)
	$(CCAUX) $(O)genarch genarch.c

genconf: genconf.c $(stdpre_h)
	$(CCAUX) $(O)genconf genconf.c

geninit: geninit.c $(stdio__h) $(string__h)
	$(CCAUX) $(O)geninit geninit.c

INCLUDE=/usr/include
gconfig_.h: unixtail.mak echogs
	./echogs -w gconfig_.h -x 2f2a -s This file was generated automatically. -s -x 2a2f
	if ( test -f $(INCLUDE)/sys/time.h ); then ./echogs -a gconfig_.h -x 23 define SYSTIME_H;\
	fi
	if ( test -f $(INCLUDE)/dirent.h ); then ./echogs -a gconfig_.h -x 23 define DIRENT_H;\
	elif ( test -f $(INCLUDE)/sys/dir.h ); then ./echogs -a gconfig_.h -x 23 define SYSDIR_H;\
	elif ( test -f $(INCLUDE)/sys/ndir.h ); then ./echogs -a gconfig_.h -x 23 define SYSNDIR_H;\
	elif ( test -f $(INCLUDE)/ndir.h ); then ./echogs -a gconfig_.h -x 23 define NDIR_H;\
	fi

$(GS): $(ld_tr) echogs $(LIB_ALL) $(DEVS_ALL) gslib.o gconfig.o gscdefs.o
	./echogs -w ldt.tr -n - $(CCLD) $(LDFLAGS) $(XLIBDIRS) -o $(GS)
	./echogs -a ldt.tr -n -s gslib.o gconfig.o gscdefs.o -s
	cat $(ld_tr) >>ldt.tr
	./echogs -a ldt.tr -s - $(EXTRALIBS) -lm
	LD_RUN_PATH=$(XLIBDIR); export LD_RUN_PATH; $(SH) <ldt.tr

# Following is from unix-end.mak, we omit the install and tar_cat rules.
pg:
	make GENOPT='' CFLAGS='-pg -O $(GCFLAGS) $(XCFLAGS)' LDFLAGS='$(XLDFLAGS) -pg' XLIBS='Xt SM ICE Xext X11' CCLEAF='$(CCC)'

gconfigv.h: $(MAKEFILE) echogs
	$(EXP)echogs -w gconfigv.h -x 23 define USE_ASM -x 2028 -q $(USE_ASM)-0 -x 29
	$(EXP)echogs -a gconfigv.h -x 23 define USE_FPU -x 2028 -q $(FPU_TYPE)-0 -x 29
	$(EXP)echogs -a gconfigv.h -x 23 define EXTEND_NAMES 0$(EXTEND_NAMES)

